summaryrefslogtreecommitdiff
path: root/svtools
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2012-02-28 16:58:25 +0000
committerCaolán McNamara <caolanm@redhat.com>2012-02-28 16:59:01 +0000
commitac08d3f6967b241d6028d9cd17cce583ac72871e (patch)
treeb58118c044cd90c7b0f59e364bc3c1a97fb2fba5 /svtools
parentdc505d3a5cdebe6271fcd6dae7b4d69e7c1af13e (diff)
we don't want any of these to be streamed out/in as 64bit values
Diffstat (limited to 'svtools')
-rw-r--r--svtools/source/filter/wmf/emfwr.cxx8
-rw-r--r--svtools/source/filter/wmf/wmfwr.cxx10
2 files changed, 11 insertions, 7 deletions
diff --git a/svtools/source/filter/wmf/emfwr.cxx b/svtools/source/filter/wmf/emfwr.cxx
index fa42544ece6d..25fab138c30a 100644
--- a/svtools/source/filter/wmf/emfwr.cxx
+++ b/svtools/source/filter/wmf/emfwr.cxx
@@ -566,7 +566,11 @@ void EMFWriter::ImplWriteSize( const Size& rSize)
void EMFWriter::ImplWriteRect( const Rectangle& rRect )
{
const Rectangle aRect( maVDev.LogicToLogic ( rRect, maVDev.GetMapMode(), maDestMapMode ));
- m_rStm << aRect.Left() << aRect.Top() << aRect.Right() << aRect.Bottom();
+ m_rStm
+ << static_cast<sal_Int32>(aRect.Left())
+ << static_cast<sal_Int32>(aRect.Top())
+ << static_cast<sal_Int32>(aRect.Right())
+ << static_cast<sal_Int32>(aRect.Bottom());
}
// -----------------------------------------------------------------------------
@@ -753,7 +757,7 @@ void EMFWriter::ImplWriteBmpRecord( const Bitmap& rBmp, const Point& rPt,
const sal_uLong nOffPos = m_rStm.Tell();
m_rStm.SeekRel( 16 );
- m_rStm << (sal_uInt32) 0 << ( ( ROP_XOR == maVDev.GetRasterOp() && WIN_SRCCOPY == nROP ) ? WIN_SRCINVERT : nROP );
+ m_rStm << (sal_uInt32) 0 << sal_Int32( ( ROP_XOR == maVDev.GetRasterOp() && WIN_SRCCOPY == nROP ) ? WIN_SRCINVERT : nROP );
ImplWriteSize( rSz );
rBmp.Write( aMemStm, sal_True, sal_False );
diff --git a/svtools/source/filter/wmf/wmfwr.cxx b/svtools/source/filter/wmf/wmfwr.cxx
index ca0caada7e2f..9cab2f018695 100644
--- a/svtools/source/filter/wmf/wmfwr.cxx
+++ b/svtools/source/filter/wmf/wmfwr.cxx
@@ -616,8 +616,8 @@ sal_Bool WMFWriter::WMFRecord_Escape_Unicode( const Point& rPoint, const String&
SvMemoryStream aMemoryStream( nStrmLen );
Point aPt( pVirDev->LogicToLogic( rPoint, aSrcMapMode, aTargetMapMode ) );
- aMemoryStream << aPt.X()
- << aPt.Y()
+ aMemoryStream << static_cast<sal_Int32>(aPt.X())
+ << static_cast<sal_Int32>(aPt.Y())
<< nStringLen;
for ( i = 0; i < nStringLen; i++ )
aMemoryStream << rUniStr.GetChar( (sal_uInt16)i );
@@ -901,9 +901,9 @@ void WMFWriter::WMFRecord_StretchDIB( const Point & rPoint, const Size & rSize,
// erzeugt, schreiben wir zuerst die Bitmap an die richtige Position
// Und ueberschreiben hinterher den FILEHEADER mit den Parametern.
nPosAnf=pWMF->Tell(); // Position merken, wo Parameter hin sollen
*pWMF << (long)0 << (long)0; // 8 bytes auffuellen (diese 8 bytes +
// 14 bytes ueberfluessigen FILEHEADER
// = 22 bytes Parameter)
*pWMF << rBitmap; // Bitmap schreiben
// Parameter schreiben:
@@ -901,9 +901,9 @@ void WMFWriter::WMFRecord_StretchDIB( const Point & rPoint, const Size & rSize,
// Und ueberschreiben hinterher den FILEHEADER mit den Parametern.
nPosAnf=pWMF->Tell(); // Position merken, wo Parameter hin sollen
- *pWMF << (long)0 << (long)0; // 8 bytes auffuellen (diese 8 bytes +
- // 14 bytes ueberfluessigen FILEHEADER
- // = 22 bytes Parameter)
+ *pWMF << (sal_Int32)0 << (sal_Int32)0; // 8 bytes auffuellen (diese 8 bytes +
+ // 14 bytes ueberfluessigen FILEHEADER
+ // = 22 bytes Parameter)
*pWMF << rBitmap; // Bitmap schreiben
// Parameter schreiben: